"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
const commandLineArgs = require("command-line-args");
const chalk = require("chalk");
const shared_1 = require("../../../shared");
const index_1 = require("../private/index");
const index_2 = require("./index");
function handler(argv, ssmOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        const subCommand = argv.shift();
        const opts = commandLineArgs(index_2.options, {
            argv: argv,
            partial: true,
        });
        if (!Object.keys(index_1.subCommands).includes(subCommand)) {
            console.log(`- please choose a ${chalk.italic("valid")} ${chalk.bold.yellow("SSM")} sub-command: ${Object.keys(index_1.subCommands).join(", ")}`);
            console.log();
            process.exit();
        }
        const serverless = yield shared_1.isServerless();
        if (serverless && serverless.isUsingTypescriptMicroserviceTemplate && !serverless.hasServerlessConfig) {
            yield shared_1.buildLambdaTypescriptProject();
        }
        try {
            yield index_1.subCommands[subCommand].execute(argv, ssmOptions);
        }
        catch (e) {
            console.log(chalk `{red - Ran into error when running "ssm ${subCommand}":}\n  - ${e.message}\n`);
            console.log(chalk `{grey - ${e.stack}}`);
            process.exit(1);
        }
    });
}
exports.handler = handler;
