"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findOrgFromGitRemote = void 0;
const shared_1 = require("../../shared");
/**
 * Looks in the **git** remotes and -- favoring "origin" -- trys to determine
 * what the organization or user the repo is published under. If there are no remotes, or there
 * is any other failure to find the org name this function will return `false`.
 */
function findOrgFromGitRemote(baseDir) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            baseDir = baseDir ? baseDir : process.cwd();
            const remotes = yield shared_1.getGitRemotes(baseDir);
            if (remotes.length === 0) {
                console.log("no remotes!");
                return false;
            }
            const origin = remotes.find((r) => r.name === "origin");
            const findOrg = /.*:(.*)\//gm;
            const [_, org] = origin
                ? findOrg.exec(origin.refs.fetch || origin.refs.push)
                : findOrg.exec(remotes[0].refs.fetch || remotes[0].refs.push);
            return org;
        }
        catch (e) {
            return false;
        }
    });
}
exports.findOrgFromGitRemote = findOrgFromGitRemote;
