"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGitRemotes = void 0;
const git_1 = require("./git");
/**
 * returns a list of defined _remotes_ for the git repo; each remote "name" will have
 * both a "fetch" and "push" reference defined. If no remotes are found then an empty
 * array will be returned.
 *
 * Note: the repo is presumed to be based in the CWD, if another directory
 * is intended then this must be passed in as the `baseDir` parameter
 */
function getGitRemotes(baseDir) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            baseDir = baseDir ? baseDir : process.cwd();
            const g = git_1.git(baseDir);
            const remotes = yield g.getRemotes(true);
            return remotes.length > 0 ? remotes : [];
        }
        catch (e) {
            return [];
        }
    });
}
exports.getGitRemotes = getGitRemotes;
